==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/sc.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizadore",
    "Simple file viewer with slideshow for media" : "Visualizadore de archìvios simpre cun presentatziones pro is media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mustra is ùrtimas fotografias e vìdeos de is vacàntzias comente in su tzìnema, mustra un'arrogu de s'ùrtimu romanzu tuo deretu dae Nextcloud, sèbera sa mègius GIF de sa regorta gràtzias a s'anteprima de is archìvios tuos preferidos e àteru ancora!",
    "Your browser does not support audio." : "Su navigadore tuo non suportat s'àudio.",
    "Error loading {name}" : "Errore de carrigamentu de {name}",
    "Unsaved changes" : "Mudas non sarvadas",
    "Your browser does not support videos." : "Su navigadore tuo non suportat vìdeos.",
    "Edit" : "Modìfica",
    "Open sidebar" : "Aberi s'istanca laterale",
    "Download" : "Iscàrriga",
    "Delete" : "Cantzella",
    "There is no plugin available to display this file type" : "Non b'at peruna estensione pro visualizare custa genia de archìviu",
    "View" : "Visualiza",
    "Name" : "Nùmene",
    "Save" : "Sarva",
    "Back" : "In segus",
    "Loading …" : "Carrigamentu …",
    "Reset" : "Torra a impostare",
    "Cancel" : "Annulla",
    "Continue" : "Sighi",
    "Undo" : "Annulla",
    "Redo" : "Torra a fàghere",
    "Zoom in" : "Ammània",
    "Original" : "Originale",
    "Custom" : "Personaliza",
    "Value" : "Balore",
    "Image" : "Imàgine",
    "Text" : "Testu",
    "Size" : "Mannària",
    "Position" : "Positzione",
    "Extension" : "Estensione",
    "Name is required." : "Su nùmene est rechertu: ",
    "Quality" : "Calidade"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.5.tgz: nextcloud/apps/viewer/l10n/sc.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizadore",
    "Simple file viewer with slideshow for media" : "Visualizadore de archìvios simpre cun presentatziones pro is media",
    "Your browser does not support audio." : "Su navigadore tuo non suportat s'àudio.",
    "Error loading {name}" : "Errore de carrigamentu de {name}",
    "Image saved" : "Imàgines sarvadas",
    "Unsaved changes" : "Mudas non sarvadas",
    "Your browser does not support videos." : "Su navigadore tuo non suportat vìdeos.",
    "Edit" : "Modìfica",
    "Open sidebar" : "Aberi s'istanca laterale",
    "Download" : "Iscàrriga",
    "Delete" : "Cantzella",
    "There is no plugin available to display this file type" : "Non b'at peruna estensione pro visualizare custa genia de archìviu",
    "View" : "Visualiza",
    "Name" : "Nùmene",
    "Save" : "Sarva",
    "Back" : "In segus",
    "Loading …" : "Carrigamentu …",
    "Reset" : "Torra a impostare",
    "Cancel" : "Annulla",
    "Continue" : "Sighi",
    "Undo" : "Annulla",
    "Redo" : "Torra a fàghere",
    "Zoom in" : "Ammània",
    "Original" : "Originale",
    "Custom" : "Personaliza",
    "Value" : "Balore",
    "Image" : "Imàgine",
    "Text" : "Testu",
    "Size" : "Mannària",
    "Position" : "Positzione",
    "Extension" : "Estensione",
    "Name is required." : "Su nùmene est rechertu: ",
    "Quality" : "Calidade",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mustra is ùrtimas fotografias e vìdeos de is vacàntzias comente in su tzìnema, mustra un'arrogu de s'ùrtimu romanzu tuo deretu dae Nextcloud, sèbera sa mègius GIF de sa regorta gràtzias a s'anteprima de is archìvios tuos preferidos e àteru ancora!"
},
"nplurals=2; plural=(n != 1);");
